import Connection from "@/api/connection";
import ServiceAuth from "@/api/services/authenticate";
import ServiceConfig from "@/api/services/config";
import ServiceProfiles from "@/api/services/profiles";
import ServiceActivities from "@/api/services/activities";
import ServiceMacros from "@/api/services/macros";
import ServiceIntegrations from "@/api/services/integrations";
import ServiceRemotes from "@/api/services/remotes";
import ServiceIr from "@/api/services/ir";
import PingApi from "@/api/connection/ping";
import ServiceResources from "@/api/services/resources";
import ServiceDocks from "@/api/services/docks";
import ServiceLogs from "@/api/services/logs";

function getBaseUrl(): string {
  return import.meta.env.VITE_API_HOST || import.meta.env.BASE_URL;
}

const baseUrl = getBaseUrl();
const ApiConnection: Connection = new Connection({
  baseUrl,
  user: import.meta.env.VITE_API_USER,
});
ApiConnection.addService("auth", new ServiceAuth(ApiConnection));
ApiConnection.addService("config", new ServiceConfig(ApiConnection));
ApiConnection.addService("profiles", new ServiceProfiles(ApiConnection));
ApiConnection.addService("activities", new ServiceActivities(ApiConnection));
ApiConnection.addService("macros", new ServiceMacros(ApiConnection));
ApiConnection.addService("intg", new ServiceIntegrations(ApiConnection));
ApiConnection.addService("remotes", new ServiceRemotes(ApiConnection));
ApiConnection.addService("ir", new ServiceIr(ApiConnection));
ApiConnection.addService("resources", new ServiceResources(ApiConnection));
ApiConnection.addService("docks", new ServiceDocks(ApiConnection));
ApiConnection.addService("logs", new ServiceLogs(ApiConnection));

export const ApiPinger = new PingApi(ApiConnection.rest());

export default ApiConnection;
