import BaseService from "@/api/services/BaseService";
import type ServiceInterface from "@/api/services/ServiceInterface";
import type { Macro, MacroNewData, MacroUpdate } from "@/types/macro";

export default class ServiceMacros
  extends BaseService
  implements ServiceInterface
{
  async getAll(): Promise<Macro[]> {
    const response = await this.rest.request({
      url: "/api/macros",
      method: "get",
    });
    return response.data || [];
  }

  async getMacro(macro_id: string): Promise<Macro> {
    const response = await this.rest.request({
      url: `/api/macros/${macro_id}`,
      method: "get",
    });
    return response.data as Macro;
  }

  async createNewMacro(data: MacroNewData): Promise<Macro> {
    const response = await this.rest.request({
      url: "/api/macros",
      method: "post",
      data,
    });
    return response.data || {};
  }

  async cloneFrom(newMacro: MacroNewData, clone_from: string): Promise<Macro> {
    const data = {
      ...newMacro,
      clone_from,
    };
    return this.createNewMacro(data);
  }

  async update(macro_id: string, data: MacroUpdate): Promise<Macro> {
    const response = await this.rest.request({
      url: `/api/macros/${macro_id}`,
      method: "patch",
      data,
    });
    return response.data || {};
  }

  async delete(data: Macro): Promise<boolean> {
    const response = await this.rest.request({
      url: `/api/macros/${data.entity_id}`,
      method: "delete",
    });
    return response.data?.code === "OK";
  }
}
