import BaseService from "@/api/services/BaseService";
import type ServiceInterface from "@/api/services/ServiceInterface";
import type { AxiosError } from "axios";
import type { ApiErrorResponse } from "@/types/rest";
import type {
  ResourceItem,
  SupportedResource,
  UploadResult,
} from "@/types/resources";

export default class ServiceResources
  extends BaseService
  implements ServiceInterface
{
  async getSupportedResources(): Promise<SupportedResource[]> {
    const response = await this.rest.request({
      url: "/api/resources",
      method: "get",
    });
    return response.data || [];
  }

  async loadItems(type: string): Promise<ResourceItem[]> {
    return this.rest.pagedGet(
      {
        url: `/api/resources/${type}`,
      },
      50
    );
  }

  async upload(type: string, file: any): Promise<UploadResult> {
    return new Promise((resolve, reject) => {
      const data = new FormData();
      data.append("file", file);
      this.rest
        .request({
          method: "post",
          url: `/api/resources/${type}`,
          data,
          headers: {
            "Content-Type": "multipart/form-data",
          },
        })
        .then((response) => {
          resolve({
            success: true,
            response: response.data as ResourceItem,
          });
        })
        .catch((error) => {
          let response = error;
          if (this.rest.isUploadError(error)) {
            response = (error as AxiosError).response?.data as ApiErrorResponse;
          }
          reject({
            success: false,
            response,
          });
        });
    });
  }

  async deleteResource(file: ResourceItem): Promise<boolean> {
    const response = await this.rest.request({
      method: "delete",
      url: `/api/resources/${file.type}/${file.id}`,
    });
    return response.data?.code === "OK";
  }
}
