import { createApp } from "vue";
import { createPinia } from "pinia";

import App from "./App.vue";
import router from "./mixins/router";
import i18n from "./i18n";
import { configStore } from "@/stores/config";

// @ts-ignore
import vSelect from "vue-select";
// @ts-ignore
import VueGridLayout from "vue-grid-layout";
import ApiConnection, { ApiPinger } from "@/api";
// vue-datepicker
import VueDatePicker from '@vuepic/vue-datepicker';
import '@vuepic/vue-datepicker/dist/main.css';
//click-outside-vue3
// @ts-ignore
import vClickOutside from "click-outside-vue3";

const app = createApp(App);
app.use(createPinia());
app.use(router);
app.use(VueGridLayout);
app.use(vClickOutside);
app.component("v-select", vSelect);
app.component('VueDatePicker', VueDatePicker);

const config = configStore();
config.$subscribe((mutation, state) => {
  const locale: string = state?.config?.localization?.language_code || "";
  const list: string[] = Array.from(i18n.global.availableLocales);
  if (locale && list.includes(locale)) {
    // @ts-ignore
    i18n.global.locale.value = locale;
  }
});
app.use(i18n);

app.mount("#app");

// @ts-ignore
window.UC = {
  app,
  api: ApiConnection,
  ping: ApiPinger,
};
