import type { ActivityUserInterfaceItem } from "@/types/activity";

import ComponentButtonIcon from "@/components/elements/ui/ComponentButtonIcon.vue";
import ComponentButtonText from "@/components/elements/ui/ComponentButtonText.vue";
import ComponentButtonNumpad from "@/components/elements/ui/ComponentButtonNumpad.vue";

export function getComponent(type: string) {
  if (type === "icon") {
    return ComponentButtonIcon;
  }
  if (type === "text") {
    return ComponentButtonText;
  }
  if (type === "numpad") {
    return ComponentButtonNumpad;
  }
  console.warn("Unknonw component type: " + type);
  return null;
}

export function getComponentClasses(
  type: string,
  settings: ActivityUserInterfaceItem | null
) {
  const classList = ["component"];
  classList.push("component--" + type);

  if (type === "text" || type === "icon") {
    classList.push("component--button");
  }
  if (type === "text") {
    classList.push("component--button-text");
  }
  if (type === "icon") {
    classList.push("component--button-with-icon");
  }

  if (settings) {
    classList.push("component--configured");
  }
  return classList;
}

export function getComponentPool(): ActivityUserInterfaceItem[] {
  return [
    {
      type: "icon",
      icon: "uc:tv",
      size: { width: 1, height: 1 },
      location: {
        x: 0,
        y: 0,
      },
    },
    {
      type: "text",
      text: "TEXT",
      size: { width: 1, height: 1 },
      location: {
        x: 0,
        y: 0,
      },
    },
    // TODO: Re-add when numpad is implemented
    // {
    //   type: "numpad",
    //   size: { width: 4, height: 6 },
    //   location: {
    //     x: 0,
    //     y: 0,
    //   },
    // },
  ];
}
