import type {
  AvailableEntity,
  ConfiguredEntity,
} from "@/types/integrationInstance";
import type { Activity } from "@/types/activity";
import type { Remote } from "@/types/remote";

import { searchLanguageText } from "@/mixins/translatedProperty";

export function isEntityMatchFilter(entity: ConfiguredEntity, search: string) {
  if (!search) {
    return true;
  }
  return (
    searchLanguageText(entity.name, search) ||
    searchLanguageText(entity.description, search) ||
    entity.entity_id.toLowerCase().includes(search) ||
    entity.entity_type.toLowerCase().includes(search) ||
    (entity.device_class || "").toLowerCase().includes(search)
  );
}

const iconMap: Record<string, string> = {
  button: "power-on",
  cover: "blind",
  media_player: "music",
  macro: "activity",
};

export function getDefaultEntityIcon(
  entity: AvailableEntity | ConfiguredEntity | Activity | Remote
) {
  let icon = (entity as any)?.icon;
  if (icon) {
    return icon;
  }
  icon = (iconMap[entity.entity_type] || entity.entity_type).replace("_", "-");
  return "uc:" + icon;
}
