import { onErrorCaptured } from "vue";
import { addError } from "@/stores/messages";
import ApiConnection from "@/api";
import type { ComposerTranslation } from "vue-i18n";

function initCaptureErrorCaptured(
  t: ComposerTranslation,
  messageKey: string,
  group: string
) {
  onErrorCaptured((err, instance, info) => {
    if (err.name !== "CanceledError") {
      addError({
        id: err.message,
        message: t(messageKey, {
          msg: err.message,
          info,
        }),
      });
    }
    console.groupCollapsed(`[${group}] [${info}]`);
    console.error(err);
    console.log(instance);
    console.log(info);
    console.groupEnd();
    return false;
  });
}

export function useAppErrorCapture(t: ComposerTranslation) {
  initCaptureErrorCaptured(t, "message.app_error", "AppError");
}

export function useViewErrorCapture(t: ComposerTranslation) {
  initCaptureErrorCaptured(t, "message.view_error", "ViewError");
}

export function useComponentErrorCapture(t: ComposerTranslation) {
  initCaptureErrorCaptured(t, "message.component_error", "ComponentError");
}

export function getErrorMessage(e: any, translate = "dock.change.error") {
  let msg = "";
  const status = (e as any).response?.status || 500;
  let code = 500;
  if (
    ApiConnection.rest().isConnectionError(e) &&
    (e as any).response?.data?.message
  ) {
    msg = (e as any).response?.data?.message;
    code = (e as any).response?.data?.code ?? code;
  } else {
    msg = String(e);
  }
  return {
    translate,
    args: {
      code,
      status,
      msg,
    },
  };
}

export function errorOnChange(e: any, translate = "dock.change.error") {
  const err = getErrorMessage(e, translate);
  addError(err);
}
