import { createRouter, createWebHashHistory } from "vue-router";
import { appStateStore } from "@/stores/appState";
import HomeView from "../views/HomeView.vue";

const router = createRouter({
  history: createWebHashHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: "/",
      name: "home",
      component: HomeView,
      beforeEnter: () => {
        appStateStore().menuOpen = true;
      },
    },
    {
      path: "/integrations-devices",
      name: "integrations-devices",
      component: () => import("../views/integrations/ListView.vue"),
    },
    {
      name: "integrations-devices-edit",
      path: "/integrations-devices/:inst_id",
      component: () => import("../views/integrations/EditView.vue"),
      props: true,
    },

    {
      path: "/ui",
      name: "ui",
      component: () => import("../views/ui/ListView.vue"),
    },
    {
      name: "profile-edit",
      path: "/ui/profile/:profile_id",
      component: () => import("../views/ui/ProfileEditView.vue"),
      props: true,
    },
    {
      name: "customize",
      path: "/ui/customize/:id",
      component: () => import("../views/ui/CustomizeView.vue"),
      props: true,
    },

    {
      path: "/activities",
      name: "activities",
      component: () => import("../views/activities/ListView.vue"),
    },
    {
      name: "macro-edit",
      path: "/activities/macro/:macro_id",
      component: () => import("../views/activities/MacroEditView.vue"),
      props: true,
    },
    {
      name: "activity-ui-edit",
      path: "/activities/activity/:activity_id/ui",
      component: () => import("../views/activities/UiEditView.vue"),
      props: true,
    },
    {
      name: "activity-edit",
      path: "/activities/activity/:activity_id",
      component: () => import("../views/activities/ActivityEditView.vue"),
      props: true,
    },

    {
      path: "/remotes",
      name: "remotes",
      component: () => import("../views/remote/ListView.vue"),
    },
    {
      path: "/remotes/:id",
      name: "remote-edit",
      component: () => import("../views/remote/EditView.vue"),
      props: true,
    },
    {
      path: "/settings",
      name: "settings",
      component: () => import("../views/settings/ListView.vue"),
    },
  ],
});

export default router;
