import { defineStore } from "pinia";
import { ApiPinger } from "@/api";

import { configStore } from "@/stores/config";
import { authStorage } from "@/stores/auth";
import { LoginState } from "@/types/enums";
import PingApi from "@/api/connection/ping";

import type { AuthStore } from "@/stores/auth";

function setSocketPing() {
  configStore().getAll();
  PingApi.useSocket();
}
function setRestPing() {
  PingApi.useRest();
}

function changePing(authState: any, appState: any) {
  if (authState && authState.authenticated === LoginState.AUTHORISED) {
    setSocketPing();
    appState.connected = true;
  } else {
    setRestPing();
  }
}

let authStore: AuthStore;

export const appStateStore = defineStore({
  id: "appState",
  state: () => ({
    inited: false,
    menuOpen: false,
    connected: null as boolean | null,
    modalPool: [] as string[],
  }),
  actions: {
    init() {
      if (this.$state.inited) {
        return;
      }
      authStore = authStorage() as AuthStore;
      this.$state.inited = true;

      ApiPinger.addStateChangeCallback(
        "connect",
        (state) => {
          if (this.$state.connected === state) {
            return;
          }

          this.$state.connected = state;
          if (
            state &&
            authStore.$state.authenticated === LoginState.AUTHORISED
          ) {
            setSocketPing();
            this.$state.connected = true;
          } else {
            setRestPing();
          }
        },
        false,
        true
      );

      authStore.$onAction(({ name, store, after }) => {
        if (name !== "authenticate" && name !== "logout") {
          return;
        }

        const beforeState = store.$state.authenticated;

        after((result) => {
          if (name === "authenticate") {
            this.$state.connected =
              store.$state.authenticated === LoginState.AUTHORISED;
          }
          if (beforeState === store.$state.authenticated) {
            return;
          }

          changePing(store.$state, this.$state);
        });
      });
      authStore.$subscribe((mutation, state) => {
        this.$state.connected = state.authenticated === LoginState.AUTHORISED;
        changePing(state, this.$state);
      });
    },

    toggleMenu() {
      this.$state.menuOpen = !this.$state.menuOpen;
    },
  },
});
