import { defineStore } from "pinia";
import ApiConnection from "@/api";
import type { Macro, MacroNewData, MacroUpdate } from "@/types/macro";

const API = ApiConnection.macros;

export const macrosStore = defineStore({
  id: "macros",
  state: () => ({
    inited: false,
    macros: [] as Macro[] | [],
  }),

  actions: {
    init() {
      if (this.$state.inited) {
        return;
      }
      this.$state.inited = true;
      ApiConnection.websocket().addMessageCallback("macro", (data) => {
        if (
          data.msg === "entity_change" &&
          data.msg_data?.new_state?.entity_type === "macro"
        ) {
          this.getAll();
        }
        this.socketUpdate(data.msg_data || {});
      });
    },

    async getAll(): Promise<Macro[]> {
      this.init();
      try {
        const items = await API.getAll();
        this.$state.macros = items;
        return items;
      } catch (e) {
        return [];
      }
    },

    async getMacro(macro_id: string): Promise<Macro> {
      this.init();
      return await API.getMacro(macro_id);
    },

    async socketUpdate(msg_data: Record<string, any>) {
      // This is only a placeholder action to make possible to subscribe on.
    },

    async create(macroData: MacroNewData): Promise<Macro> {
      return await API.createNewMacro(macroData);
    },

    async clone(newMacro: MacroNewData, clone_from: string): Promise<Macro> {
      return await API.cloneFrom(newMacro, clone_from);
    },

    async update(macro_id: string, macro: MacroUpdate): Promise<Macro> {
      return await API.update(macro_id, macro);
    },

    async delete(macro: Macro): Promise<Macro[]> {
      await API.delete(macro);
      return this.getAll();
    },
  },
});
