import { defineStore } from "pinia";
import type { FlashMessageData, FlashMessageItem } from "@/types/flashMessages";
import { FlashMessageType } from "@/types/enums";
import Api from "@/api";

let store: any;
export function addMessage(item: FlashMessageItem) {
  if (!store) {
    store = messagesStore();
  }
  store.add(item);
}

export function errorOnLoad(error: any) {
  if (
    Api.rest().isUnauthorizedError(error) ||
    Api.rest().isCancelError(error)
  ) {
    return;
  }
  addError({
    translate: "message.error_load",
    args: {
      msg: String(error),
    },
  });
}

export function addError(message: FlashMessageData) {
  addMessage({
    ...message,
    type: FlashMessageType.error,
    timeout: -1,
  });
}
export function addInfo(message: FlashMessageData) {
  addMessage({
    id: "ok",
    ...message,
    type: FlashMessageType.info,
  });
}

export const messagesStore = defineStore({
  id: "messages",
  state: () => ({
    pool: new Map<string, FlashMessageItem>(),
  }),
  actions: {
    add(item: FlashMessageItem) {
      const date = new Date();
      const message = {
        id: null,
        timeout: 8000,
        onClose: null,
        closeable: true,
        ...item,
      } as FlashMessageItem;

      if (!message.id) {
        message.id = date.getTime() + "." + date.getMilliseconds();
      }
      if (!message.timeout) {
        message.timeout = 8000;
      }
      if (typeof message.closeable === "undefined") {
        message.closeable = true;
      }

      this.$state.pool.set(message.id, message);
      if (message.timeout > 0) {
        setTimeout(() => {
          if (typeof message.onClose === "function") {
            message.onClose();
          }
          this.remove(message.id as string);
        }, message.timeout);
      }
    },

    remove(item_id: string) {
      this.$state.pool.delete(item_id);
    },

    error(message: FlashMessageData) {
      this.add({
        ...message,
        type: FlashMessageType.error,
      });
    },

    info(message: FlashMessageData) {
      this.add({
        ...message,
        type: FlashMessageType.info,
      });
    },
  },
});
