import type { IconIdentifier, LanguageText } from "@/types/config";

import type { IntegrationId } from "@/types/integrationInstance";
import type {
  ActivitySequences,
  ActivityUserInterface,
  DeviceButtonMapping,
} from "@/types/activity";
import type { DeviceType } from "@/types/enums";

export type RemoteOverview = {
  entity_id: string;
  entity_type: "remote";
  integration_id: IntegrationId;
  device_class?: string;
  name: LanguageText;
  icon?: IconIdentifier;
  description?: LanguageText;
  features?: ["send"];
  options?: {
    editable?: boolean;
  };
};

export type Remote = {
  entity_id: string;
  entity_type: string;
  integration_id: string;
  device_class?: string;
  name: LanguageText;
  icon?: IconIdentifier;
  description?: LanguageText;
  features: string[];
  options?: {
    editable?: boolean;
    ir?: {
      codeset?: {
        id?: string;
        name?: string;
        type?: string;
      };
      output?: {
        device_id?: string;
        port_id?: string;
      };
    };
    simple_commands?: string[];
    button_mapping?: DeviceButtonMapping[];
    user_interface?: ActivityUserInterface;
  };
};

export type RemoteUpdate = {
  name?: LanguageText;
  icon?: IconIdentifier;
  description?: LanguageText;
  options?: {
    entity_ids?: string[];
    sequences?: ActivitySequences;
    button_mapping?: DeviceButtonMapping[];
    user_interface?: ActivityUserInterface;
    ir?: {
      codeset?: {
        id: string;
      };
      output?: {
        device_id: string;
        port_id: string;
      };
    };
  };
};

export type RemoteNewData = {
  name: LanguageText;
  icon?: IconIdentifier;
  description?: LanguageText;

  clone_from?: string;
  codeset_id?: string;
  custom_codeset?: {
    manufacturer?: string;
    manufacturer_id?: string;
    device_name: string;
    device_type?: DeviceType;
  };
};

export type PageItem = {
  entity_id?: string;
  group_id?: string;
  pos: number;
};
